==> libvirt_provider-0.0.0a1-py3-none-any.whl: libvirt_provider/cli/helpers.py <==
import asyncio
from libvirt_provider.client import new_client
from libvirt_provider.defaults import LIBVIRT


def strip_argument_prefix(arguments, prefix=""):
    return {k.replace(prefix, ""): v for k, v in arguments.items()}


def get_arguments(arguments, startswith=""):
    return {k: v for k, v in arguments.items() if k.startswith(startswith)}


def extract_arguments(arguments, argument_groups):
    found_kwargs, remaining_kwargs = {}, {}
    for argument_group in argument_groups:
        group_args = get_arguments(arguments, argument_group.lower())
        found_kwargs.update(group_args)
    remaining_kwargs = {
        k: v for k, v in arguments.items() if k not in found_kwargs and v
    }
    return found_kwargs, remaining_kwargs


def strip_argument_group_prefix(arguments, argument_groups):
    args = {}
    for argument_group in argument_groups:
        group_arguments = get_arguments(arguments, argument_group.lower())
        args.update(
            strip_argument_prefix(group_arguments, argument_group.lower() + "_")
        )
    return args


def get_argument_groups(arguments, groups=None):
    if not groups:
        groups = []

    args = []
    for group in groups:
        if group in arguments:
            args.append(getattr(arguments, group))
    return args


def import_from_module(module_path, module_name, func_name):
    module = __import__(module_path, fromlist=[module_name])
    return getattr(module, func_name)


def cli_exec(arguments):
    # Actions determines which function to execute
    module_path = arguments.pop("module_path")
    module_name = arguments.pop("module_name")
    func_name = arguments.pop("func_name")

    if "positional_arguments" in arguments:
        positional_arguments = arguments.pop("positional_arguments")
    else:
        positional_arguments = []

    if "provider_groups" in arguments:
        provider_groups = arguments.pop("provider_groups")
    else:
        provider_groups = []

    if "argument_groups" in arguments:
        argument_groups = arguments.pop("argument_groups")
    else:
        argument_groups = []

    func = import_from_module(module_path, module_name, func_name)
    if not func:
        return False

    ## Extract the arguments provided
    driver_kwargs, remaining_driver_kwargs = extract_arguments(
        arguments, provider_groups
    )
    driver_kwargs = strip_argument_group_prefix(driver_kwargs, provider_groups)
    driver_provider = driver_kwargs.pop("name", LIBVIRT)
    client = new_client(driver_provider, **driver_kwargs)

    action_kwargs, remaining_action_kwargs = extract_arguments(
        remaining_driver_kwargs, argument_groups
    )
    action_kwargs = strip_argument_group_prefix(action_kwargs, argument_groups)
    if remaining_action_kwargs:
        print("Unused arguments: {}".format(remaining_action_kwargs))
    action_args = positional_arguments
    return asyncio.run(func(client, *action_args, **action_kwargs))

==> libvirt_provider-0.0.1a8-py3-none-any.whl: libvirt_provider/cli/helpers.py <==
# Copyright (C) 2024  rasmunk
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

import asyncio
from libvirt_provider.client import new_client
from libvirt_provider.defaults import LIBVIRT


def strip_argument_prefix(arguments, prefix=""):
    return {k.replace(prefix, ""): v for k, v in arguments.items()}


def get_arguments(arguments, startswith=""):
    return {k: v for k, v in arguments.items() if k.startswith(startswith)}


def extract_arguments(arguments, argument_groups):
    found_kwargs, remaining_kwargs = {}, {}
    for argument_group in argument_groups:
        group_args = get_arguments(arguments, argument_group.lower())
        found_kwargs.update(group_args)
    remaining_kwargs = {
        k: v for k, v in arguments.items() if k not in found_kwargs and v
    }
    return found_kwargs, remaining_kwargs


def strip_argument_group_prefix(arguments, argument_groups):
    args = {}
    for argument_group in argument_groups:
        group_arguments = get_arguments(arguments, argument_group.lower())
        args.update(
            strip_argument_prefix(group_arguments, argument_group.lower() + "_")
        )
    return args


def get_argument_groups(arguments, groups=None):
    if not groups:
        groups = []

    args = []
    for group in groups:
        if group in arguments:
            args.append(getattr(arguments, group))
    return args


def import_from_module(module_path, module_name, func_name):
    module = __import__(module_path, fromlist=[module_name])
    return getattr(module, func_name)


def cli_exec(arguments):
    # Actions determines which function to execute
    module_path = arguments.pop("module_path")
    module_name = arguments.pop("module_name")
    func_name = arguments.pop("func_name")

    if "positional_arguments" in arguments:
        positional_arguments = arguments.pop("positional_arguments")
    else:
        positional_arguments = []

    if "provider_groups" in arguments:
        provider_groups = arguments.pop("provider_groups")
    else:
        provider_groups = []

    if "argument_groups" in arguments:
        argument_groups = arguments.pop("argument_groups")
    else:
        argument_groups = []

    func = import_from_module(module_path, module_name, func_name)
    if not func:
        return False

    # Extract the arguments provided
    driver_kwargs, remaining_driver_kwargs = extract_arguments(
        arguments, provider_groups
    )
    driver_kwargs = strip_argument_group_prefix(driver_kwargs, provider_groups)
    driver_provider = driver_kwargs.pop("name", LIBVIRT)
    client = new_client(driver_provider, **driver_kwargs)

    action_kwargs, remaining_action_kwargs = extract_arguments(
        remaining_driver_kwargs, argument_groups
    )
    action_kwargs = strip_argument_group_prefix(action_kwargs, argument_groups)
    if remaining_action_kwargs:
        print("Unused arguments: {}".format(remaining_action_kwargs))
    action_args = positional_arguments
    return asyncio.run(func(client, *action_args, **action_kwargs))
